#!/usr/bin/env python
#
# Duo, A crazy eights game.
# Copyright (C) 2009 The Duo developers.
#
# This file is part of Duo.
#
# Duo is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


from distutils.core import setup

import glob
import os
import subprocess
import shutil
import sys

import duo


def pack_pmw():
    """Try to pack the Pmw package.

    This operation is needed to distribute it inside a MS Windows
    executable.
    """
    try:
        import Pmw

        bin_path = os.path.join(Pmw._dirpath, Pmw._instdirs[0], 'bin')
        lib_path = os.path.join(Pmw._dirpath, Pmw._instdirs[0], 'lib')

        subprocess.call(
            [sys.executable, os.path.join(bin_path, 'bundlepmw.py'), lib_path])
        shutil.copyfile(os.path.join(lib_path, 'PmwBlt.py'), "PmwBlt.py")
        shutil.copyfile(os.path.join(lib_path, 'PmwColor.py'), "PmwColor.py")
        return True

    except ImportError, e:
        print 'Failed to package Pmw:', e
    except OSError, e:
        print 'Failed to pack Pmw:', e


# Check preprocessing for exe build.
if 'py2exe' in sys.argv:
    try:
        import py2exe
        if not pack_pmw():
            exit(1)

    except ImportError, e:
        print 'Failed to import py2exe:', e
        exit(1)

# Create locales.
if 'build' in sys.argv or 'py2exe' in sys.argv:
    try:
        subprocess.call(['make-locale.py'])

    except Exception, e:
        print 'Failed to produce the locales:', e

data = [
    ('images/classic', glob.glob('images/classic/*'))]

for folder in os.listdir('locale'):
    data.append(
        ('locale/' + folder + '/LC_MESSAGES',
         ['locale/' + folder + '/LC_MESSAGES/duo.mo']))


# Proceed to standard installation.
setup(
    name = 'Duo',
    version = duo.__version__,
    author = 'David Soulayrol',
    author_email = 'david.soulayrol@gmail.com',
    url = 'http://duo.tuxfamily.org',
    description = 'A Crazy Eights Card Game',
    download_url = '',

    packages = ['duo', 'duo/ai', 'duo/ui', 'duo/tools', 'duo/transport'],
    scripts=['duo.py'],
    data_files = data,

    console = ['duo.py'],

    # In Duo ui, ai, and transport modules are only loaded on demand,
    # depending on the choice of the user. So hereafter, some duo
    # modules are forced in because the analyser doesn't see they can
    # be indirectly loaded.
    options={'py2exe':
             {'includes': ['duo.ui.tk',
                           'duo.ai.camille',
                           'duo.transport.local']}}
)
